@@ -17,10 +17,9 @@
 
 from __future__ import print_function
 
-import collections
-
 from keystoneauth1.identity import generic as ks_id
 from keystoneauth1 import session
+from six import string_types
 from swiftclient.client import Connection
 
 
@@ -49,31 +48,7 @@ def get_swift_client(preauthurl, preauthtoken):
                       max_backoff=120)
 
 
-def get_nested(data, name, path):
-    # Finds and returns a property from a nested dictionary by
-    # following a path of a defined set of property names and types.
-
-    def deep_find_key(key_data, data, name):
-        key, instance_type, instance_name = key_data
-        if key in data.keys():
-            if not isinstance(data[key], instance_type):
-                raise ValueError("The '{}' property of '{}' must be a {}."
-                                 "".format(key, name, instance_name))
-            return data[key]
-        for item in data.values():
-            if isinstance(item, collections.Mapping):
-                return deep_find_key(key_data, item, name)
-        return None
-
-    if not isinstance(data, collections.Mapping):
-        raise ValueError(
-            "'{}' is not a valid resource.".format(name))
-
-    current_value = data
-    while len(path) > 0:
-        key_data = path.pop(0)
-        current_value = deep_find_key(key_data, current_value, name)
-        if current_value is None:
-            break
-
-    return current_value
+def filtered(obj):
+    """Only return properties of obj whose value can be properly serialized."""
+    return {k: v for k, v in obj.__dict__.items()
+            if isinstance(v, (string_types, int, list, dict, type(None)))}
